@@ -9,6 +9,7 @@ import (
 	"miniflux.app/integration/espial"
 	"miniflux.app/integration/instapaper"
 	"miniflux.app/integration/linkding"
+	"miniflux.app/integration/matrixbot"
 	"miniflux.app/integration/nunuxkeeper"
 	"miniflux.app/integration/pinboard"
 	"miniflux.app/integration/pocket"
@@ -54,6 +55,7 @@ func SendEntry(entry *model.Entry, integration *model.Integration) {
 			integration.WallabagClientSecret,
 			integration.WallabagUsername,
 			integration.WallabagPassword,
+			integration.WallabagOnlyURL,
 		)
 
 		if err := client.AddEntry(entry.URL, entry.Title, entry.Content); err != nil {
@@ -109,6 +111,18 @@ func SendEntry(entry *model.Entry, integration *model.Integration) {
 	}
 }
 
+// PushEntries pushes an entry array to third-party providers during feed refreshes.
+func PushEntries(entries model.Entries, integration *model.Integration) {
+	if integration.MatrixBotEnabled {
+		logger.Debug("[Integration] Sending %d entries for User #%d to Matrix", len(entries), integration.UserID)
+
+		err := matrixbot.PushEntries(entries, integration.MatrixBotURL, integration.MatrixBotUser, integration.MatrixBotPassword, integration.MatrixBotChatID)
+		if err != nil {
+			logger.Error("[Integration] push entries to matrix bot failed: %v", err)
+		}
+	}
+}
+
 // PushEntry pushes an entry to third-party providers during feed refreshes.
 func PushEntry(entry *model.Entry, integration *model.Integration) {
 	if integration.TelegramBotEnabled {
