@@ -62,7 +62,7 @@ func (h *handler) submitSubscription(w http.ResponseWriter, r *http.Request) {
 		subscriptionForm.AllowSelfSignedCertificates,
 	)
 	if findErr != nil {
-		logger.Error("[UI:SubmitSubscription] %s", findErr)
+		logger.Error("[UI:SubmitSubscription] %q -> %s", subscriptionForm.URL, findErr)
 		v.Set("form", subscriptionForm)
 		v.Set("errorMessage", findErr)
 		html.OK(w, r, v.Render("add_subscription"))
